@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_indexFrameContainer.php 2578 2009-11-20 10:23:55Z fishbone $
+ * @version    SVN: $Id: admin_indexFrameContainer.php 4095 2011-05-03 04:51:22Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseFrameContainer.php');
@@ -93,14 +93,15 @@ class admin_indexFrameContainer extends BaseFrameContainer
 	 */
 	function _setTemplate($request)
 	{
-		//return '_admin';
+		global $gSystemManager;
+		
 		// 受け付けるコマンドを判断
 		$cmd = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_COMMAND);
 		if ($cmd == M3_REQUEST_CMD_SHOW_POSITION ||		// 表示位置を表示するとき
 			$cmd == M3_REQUEST_CMD_SHOW_POSITION_WITH_WIDGET){		// 表示位置を表示するとき(ウィジェット付き)
 			return '';		// デフォルトのテンプレートを使用
 		} else {
-			return '_admin';
+			return $gSystemManager->defaultAdminTemplateId();
 		}
 	}
 }
