@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseWidgetContainer.php 4114 2011-05-07 10:47:42Z fishbone $
+ * @version    SVN: $Id: baseWidgetContainer.php 4145 2011-05-17 00:27:26Z fishbone $
  * @link       http://www.magic3.org
  */
 // テンプレートライブラリ読み込み
@@ -33,6 +33,7 @@ class BaseWidgetContainer extends Core
 	protected $guidanceMessage = array();		// ガイダンス
 	protected $optionUrlParam = array();		// URLに付加する値
 	protected $localeText = array();			// ローカライズ用テキストの定義
+	protected $keepForeTaskForBackUrl = false;	// 遷移前のタスクを戻り先URLとするかどうか
 	protected $_defConfigId;					// ページ定義のウィジェット定義ID
 	protected $_defSerial;						// ページ定義のレコードシリアル番号
 	protected $_backUrl;						// 戻り先URL
@@ -145,14 +146,6 @@ class BaseWidgetContainer extends Core
 					if (!empty($value)) $this->_defConfigId = $value;
 					$value = $request->trimValueOf('_pdefserial');		// ページ定義のレコードシリアル番号
 					if (!empty($value)) $this->_defSerial = $value;
-					
-					// 戻り先URL。GETで遷移してきた場合のみ戻り先を取得。
-					if ($request->isGetMethod()){
-						$this->_backUrl = $_SERVER["HTTP_REFERER"];
-					} else {		// POSTの場合は既存値を取得
-						$value = $request->trimValueOf('_backurl');		// 戻り先URL
-						if (!empty($value)) $this->_backUrl = $value;
-					}
 				}
 				
 				$this->_assign($request, $param);
@@ -164,6 +157,32 @@ class BaseWidgetContainer extends Core
 						$this->tmpl->addVar("_widget", "_def_config", $this->_defConfigId);	// ページ定義のウィジェット定義ID
 						$this->tmpl->addVar("_widget", "_def_serial", $this->_defSerial);	// ページ定義のレコードシリアル番号
 					}
+					
+					// 戻り先URL。GETで遷移してきた場合のみ戻り先を取得。
+					if ($request->isGetMethod()){
+						if ($this->keepForeTaskForBackUrl){		// 遷移前のタスクを戻り先URLとする場合
+							// 戻り先URLを取得
+							$value = $request->trimValueOf('_backurl');		// 戻り先URL
+							if (!empty($value)) $this->_backUrl = $value;
+
+							// リファラーを解析
+							$backUrl = '';
+							if (isset($_SERVER["HTTP_REFERER"])) $backUrl = $_SERVER["HTTP_REFERER"];
+							$queryArray = array();
+							$parsedUrl = parse_url($backUrl);
+							if (!empty($parsedUrl['query'])) parse_str($parsedUrl['query'], $queryArray);		// クエリーの解析
+							$oldTask = $queryArray['task'];
+							$newTask = $request->trimValueOf('task');		// 現在のタスク
+							
+							// タスクに変更があった場合のみ戻り先URLを更新
+							if ($oldTask != $newTask) $this->_backUrl = $backUrl;
+						} else {
+							if (isset($_SERVER["HTTP_REFERER"])) $this->_backUrl = $_SERVER["HTTP_REFERER"];
+						}
+					} else {		// POSTの場合は既存値を取得
+						$value = $request->trimValueOf('_backurl');		// 戻り先URL
+						if (!empty($value)) $this->_backUrl = $value;
+					}
 					if (!empty($this->_backUrl)) $this->tmpl->addVar("_widget", "_back_url", $this->convertToDispString($this->_backUrl));	// 戻り先URL
 				}
 			}
@@ -344,6 +363,15 @@ class BaseWidgetContainer extends Core
 	{
 		$this->parseCancel = true;			// テンプレート変換処理を中断するかどうか
 	}
+	/**
+	 * 遷移前のタスクを戻り先URLとするに設定
+	 *
+	 * @return なし
+	 */
+	function setKeepForeTaskForBackUrl()
+	{
+		$this->keepForeTaskForBackUrl = true;				// 遷移前のタスクを戻り先URLとするかどうか
+	}
 	/**
 	 * ヘルプ文字列を変換
 	 *
