@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2010 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: create_std.sql 3681 2010-10-08 23:08:22Z fishbone $
+-- * @version    SVN: $Id: create_std.sql 4125 2011-05-09 05:55:32Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -112,6 +112,7 @@ CREATE TABLE content (
     cn_default           BOOLEAN        DEFAULT false                 NOT NULL,      -- デフォルトフラグ
     cn_key               VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 外部からの参照用キー
     cn_user_limited      BOOLEAN        DEFAULT false                 NOT NULL,      -- 参照ユーザを制限
+    cn_search_target     BOOLEAN        DEFAULT true                  NOT NULL,      -- 検索対象かどうか
     
     cn_check_out_user_id INT            DEFAULT 0                     NOT NULL,      -- チェックアウトユーザID(0のときはチェックイン状態)
     cn_check_out_dt      TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- チェックアウト日時
@@ -267,6 +268,7 @@ CREATE TABLE blog_entry (
     be_blog_id           VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- ブログID
     be_regist_user_id    INT            DEFAULT 0                     NOT NULL,      -- エントリー作者
     be_regist_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 投稿日時
+    be_dt                TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- ブログ記事更新日時
     be_active_start_dt   TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 公開期間(開始)
     be_active_end_dt     TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 公開期間(終了)
 
@@ -303,7 +305,7 @@ CREATE TABLE blog_comment (
     bo_regist_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 投稿日時
     
     bo_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- タイトル
-    bo_html              VARCHAR(200)   DEFAULT ''                    NOT NULL,      -- 本文HTML
+    bo_html              TEXT                                         NOT NULL,      -- 本文HTML
     bo_url               TEXT                                         NOT NULL,      -- 参照用URL
     bo_user_name         VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ユーザ名
     bo_email             VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- Eメールアドレス
@@ -907,3 +909,107 @@ CREATE TABLE mblog_member (
     PRIMARY KEY          (mb_serial),
     UNIQUE               (mb_id,        mb_history_index)
 ) TYPE=innodb;
+
+-- --------------------------------------------------------------------------------------------------
+-- イベント情報用
+-- --------------------------------------------------------------------------------------------------
+-- イベント設定マスター
+DROP TABLE IF EXISTS event_config;
+CREATE TABLE event_config (
+    eg_id                VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- ID(Key)
+    eg_value             TEXT                                         NOT NULL,      -- 値
+    eg_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 名称
+    eg_description       VARCHAR(80)    DEFAULT ''                    NOT NULL,      -- 説明
+    eg_index             INT            DEFAULT 0                     NOT NULL,      -- ソート用
+    PRIMARY KEY          (eg_id)
+) TYPE=innodb;
+
+-- イベント記事マスター
+DROP TABLE IF EXISTS event_entry;
+CREATE TABLE event_entry (
+    ee_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    ee_id                INT            DEFAULT 0                     NOT NULL,      -- エントリーID
+    ee_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
+    ee_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+    
+    ee_name              VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- エントリータイトル
+    ee_html              TEXT                                         NOT NULL,      -- エントリー本文HTML
+    ee_html_ext          TEXT                                         NOT NULL,      -- エントリー本文HTML(結果)
+    ee_summary           VARCHAR(300)   DEFAULT ''                    NOT NULL,      -- 概要
+    ee_admin_note        VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 管理者用備考
+    ee_place             VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 場所
+    ee_contact           VARCHAR(60)    DEFAULT ''                    NOT NULL,      -- 連絡先(Eメール,電話番号)
+    ee_url               TEXT                                         NOT NULL,      -- URL
+    ee_status            SMALLINT       DEFAULT 0                     NOT NULL,      -- エントリー状態(0=未設定、1=編集中、2=公開、3=非公開)
+    ee_show_comment      BOOLEAN        DEFAULT true                  NOT NULL,      -- コメントを表示するかどうか
+    ee_receive_comment   BOOLEAN        DEFAULT false                 NOT NULL,      -- コメントの受け付け可否
+    ee_user_limited      BOOLEAN        DEFAULT false                 NOT NULL,      -- 参照ユーザを制限
+    ee_start_dt          TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- イベント期間(開始)
+    ee_end_dt            TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- イベント期間(終了)
+
+    ee_check_out_user_id INT            DEFAULT 0                     NOT NULL,      -- チェックアウトユーザID(0のときはチェックイン状態)
+    ee_check_out_dt      TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- チェックアウト日時
+    ee_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
+    ee_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
+    ee_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    ee_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    ee_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (ee_serial),
+    UNIQUE               (ee_id,        ee_language_id,               ee_history_index)
+) TYPE=innodb;
+
+-- イベントコメントトラン
+DROP TABLE IF EXISTS event_comment;
+CREATE TABLE event_comment (
+    eo_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    eo_entry_id          INT            DEFAULT 0                     NOT NULL,      -- エントリーID
+    eo_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
+    eo_parent_serial     INT            DEFAULT 0                     NOT NULL,      -- 親コメントのシリアル番号
+    eo_user_id           INT            DEFAULT 0                     NOT NULL,      -- ユーザID
+    eo_regist_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 投稿日時
+    
+    eo_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- タイトル
+    eo_html              TEXT                                         NOT NULL,      -- 本文HTML
+    eo_url               TEXT                                         NOT NULL,      -- 参照用URL
+    eo_user_name         VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- ユーザ名
+    eo_email             VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- Eメールアドレス
+    eo_status            SMALLINT       DEFAULT 0                     NOT NULL,      -- 状態(0=未設定、1=非公開、2=公開)
+    
+    eo_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    eo_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    eo_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (eo_serial)
+) TYPE=innodb;
+
+-- イベントカテゴリマスター
+DROP TABLE IF EXISTS event_category;
+CREATE TABLE event_category (
+    ec_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    ec_id                VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- カテゴリID
+    ec_item_id           VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- カテゴリ項目ID(空=カテゴリ種別、空以外=カテゴリ項目)
+    ec_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
+    ec_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+
+    ec_name              VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- カテゴリ名称
+    ec_index             INT            DEFAULT 0                     NOT NULL,      -- カテゴリ項目の表示順(カテゴリ項目IDが空のときはカテゴリの表示順)
+
+    ec_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
+    ec_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
+    ec_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    ec_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    ec_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (ec_serial),
+    UNIQUE               (ec_id,        ec_item_id,  ec_language_id,  ec_history_index)
+) TYPE=innodb;
+
+-- イベント記事とイベント記事カテゴリーの対応付けマスター
+DROP TABLE IF EXISTS event_entry_with_category;
+CREATE TABLE event_entry_with_category (
+    ew_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    ew_entry_id          INT            DEFAULT 0                     NOT NULL,      -- エントリーID
+    ew_category_id       VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- カテゴリID
+    ew_category_item_id  VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- カテゴリ項目ID
+    PRIMARY KEY          (ew_serial),
+    UNIQUE               (ew_entry_id,  ew_category_id, ew_category_item_id)
+) TYPE=innodb;
+
