@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2010 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: ec.sql 4012 2011-02-23 00:12:32Z fishbone $
+-- * @version    SVN: $Id: ec.sql 4143 2011-05-16 14:22:21Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- [Eコマース標準管理メニュー]
@@ -51,16 +51,15 @@ INSERT INTO _nav_item
 (600,   0,            6,        'admin_menu', '_system',                       '',          0,               '', 'システム管理', '', '', true),
 (601,   600,          0,        'admin_menu', 'widgetlist',                    '',          0,               '', 'ウィジェット管理', 'ウィジェット管理', 'ウィジェットの追加、更新など管理を行います。', true),
 (602,   600,          1,        'admin_menu', 'userlist',                      '',          0,               '', 'ユーザ一覧', 'ユーザ一覧', 'ログイン可能なユーザを管理します。', true),
-(603,   600,          2,        'admin_menu', 'loginstatus',                   '',          0,               '', 'ログイン状況', 'ログイン状況', 'ユーザのログイン状況を表示します。', true),
-(604,   600,          3,        'admin_menu', 'analyzecalc',                  '',          0,               '',       'アクセス解析', 'アクセス解析', 'サイトへのアクセス状況を表示します。', true),
-(605,   600,          4,        'admin_menu', 'opelog',                        '',          0,               '', '運用ログ参照', '運用ログ参照', 'システムの運用状況を表示します。', true),
-(606,   600,          5,        'admin_menu', 'accesslog',                     '',          0,               '', 'アクセスログ参照', 'アクセスログ参照', 'サイトへのアクセス状況を表示します。', true),
-(607,   600,          6,        'admin_menu', 'searchwordlog',                 '',          0,               '', '検索語ログ参照', '検索語ログ参照', 'サイトで検索されたキーワードを表示します。', true),
-(608,   600,          7,        'admin_menu', 'configsys',                     '',          0,               '', 'システム情報', 'システム情報', 'システム全体の設定、運用状況を管理します。', true),
-(609,   600,          8,        'admin_menu', 'resbrowse',                     '',          0,               '', 'リソースブラウズ', 'リソースブラウズ', 'リソースファイルを管理します。', true),
-(610,   600,          9,        'admin_menu', 'master',                        '',          0,               '', 'システムマスター管理', 'システムマスター管理', 'システムに関するマスターテーブルの管理を行います。', true),
-(611,   600,          10,        'admin_menu', 'initsystem',                    '',          0,               '', 'DBメンテナンス', 'DBメンテナンス', 'データの初期化などDBのメンテナンスを行います。', true),
-(612,   600,          11,        'admin_menu', 'editmenu',                      '',          0,               '', '管理メニュー編集', '管理メニュー編集', '管理機能のメインメニューを編集します。', true),
+(603,   600,          2,        'admin_menu', 'analyzecalc',                  '',          0,               '',       'アクセス解析', 'アクセス解析', 'サイトへのアクセス状況を表示します。', true),
+(604,   600,          3,        'admin_menu', 'opelog',                        '',          0,               '', '運用ログ参照', '運用ログ参照', 'システムの運用状況を表示します。', true),
+(605,   600,          4,        'admin_menu', 'accesslog',                     '',          0,               '', 'アクセスログ参照', 'アクセスログ参照', 'サイトへのアクセス状況を表示します。', true),
+(606,   600,          5,        'admin_menu', 'searchwordlog',                 '',          0,               '', '検索語ログ参照', '検索語ログ参照', 'サイトで検索されたキーワードを表示します。', true),
+(607,   600,          6,        'admin_menu', 'configsys',                     '',          0,               '', 'システム情報', 'システム情報', 'システム全体の設定、運用状況を管理します。', true),
+(608,   600,          7,        'admin_menu', 'resbrowse',                     '',          0,               '', 'リソースブラウズ', 'リソースブラウズ', 'リソースファイルを管理します。', true),
+(609,   600,          8,        'admin_menu', 'master',                        '',          0,               '', 'システムマスター管理', 'システムマスター管理', 'システムに関するマスターテーブルの管理を行います。', true),
+(610,   600,          9,        'admin_menu', 'initsystem',                    '',          0,               '', 'DBメンテナンス', 'DBメンテナンス', 'データの初期化などDBのメンテナンスを行います。', true),
+(611,   600,          10,        'admin_menu', 'editmenu',                      '',          0,               '', '管理メニュー編集', '管理メニュー編集', '管理機能のメインメニューを編集します。', true),
 (699,   0,            7,        'admin_menu', '_699',                          '',          1,               '',          '改行', '', '', true),
 (1100,  0,            11,       'admin_menu', '_others',                       '',          0,                '',           'その他', '', '', true),
 (1101,  1100,         0,        'admin_menu', 'logout',                        '',          0,                '',                  'ログアウト', 'ログアウト', '管理機能からログアウトします。', true),
@@ -96,16 +95,15 @@ INSERT INTO _nav_item
 (10600,   0,            6,        'admin_menu.en', '_system',                       '',          0,               '', 'System Administration', '', '', true),
 (10601,   10600,          0,        'admin_menu.en', 'widgetlist',                    '',          0,               '', 'Widget Administration', 'Widget Administration', 'Administrate widgets with widget config window.', true),
 (10602,   10600,          1,        'admin_menu.en', 'userlist',                      '',          0,               '', 'User List', 'User List', 'Administrate user to login.', true),
-(10603,   10600,          2,        'admin_menu.en', 'loginstatus',                   '',          0,               '', 'Login Status', 'Login Status', 'View user login status.', true),
-(10604,   10600,          3,        'admin_menu.en', 'analyzecalc',                  '',          0,               '',       'Access Analytics', 'Access Analytics', 'Analyze site access.', true),
-(10605,   10600,          4,        'admin_menu.en', 'opelog',                        '',          0,               '', 'Operation Log', 'Operation Log', 'View system operation log.', true),
-(10606,   10600,          5,        'admin_menu.en', 'accesslog',                     '',          0,               '', 'Access Log', 'Access Log', 'View site access log.', true),
-(10607,   10600,          6,        'admin_menu.en', 'searchwordlog',                 '',          0,               '', 'Search Word Log', 'Search Word Log', 'View words to search.', true),
-(10608,   10600,          7,        'admin_menu.en', 'configsys',                     '',          0,               '', 'System Information', 'System Information', 'Configure sytem information.', true),
-(10609,   10600,          8,        'admin_menu.en', 'resbrowse',                     '',          0,               '', 'Resource Browse', 'Resource Browse', 'Administrate resource files.', true),
-(10610,   10600,          9,        'admin_menu.en', 'master',                        '',          0,               '', 'System Master', 'System Master', 'Administrate system master data.', true),
-(10611,   10600,          10,        'admin_menu.en', 'initsystem',                    '',          0,               '', 'Database Maintenance', 'Database Maintenance', 'Database maintenance such as data initializing.', true),
-(10612,   10600,          11,        'admin_menu.en', 'editmenu',                      '',          0,               '', 'Edit Administration Menu', 'Edit Administration Menu', 'Edit administration menu.', true),
+(10603,   10600,          2,        'admin_menu.en', 'analyzecalc',                  '',          0,               '',       'Access Analytics', 'Access Analytics', 'Analyze site access.', true),
+(10604,   10600,          3,        'admin_menu.en', 'opelog',                        '',          0,               '', 'Operation Log', 'Operation Log', 'View system operation log.', true),
+(10605,   10600,          4,        'admin_menu.en', 'accesslog',                     '',          0,               '', 'Access Log', 'Access Log', 'View site access log.', true),
+(10606,   10600,          5,        'admin_menu.en', 'searchwordlog',                 '',          0,               '', 'Search Word Log', 'Search Word Log', 'View words to search.', true),
+(10607,   10600,          6,        'admin_menu.en', 'configsys',                     '',          0,               '', 'System Information', 'System Information', 'Configure sytem information.', true),
+(10608,   10600,          7,        'admin_menu.en', 'resbrowse',                     '',          0,               '', 'Resource Browse', 'Resource Browse', 'Administrate resource files.', true),
+(10609,   10600,          8,        'admin_menu.en', 'master',                        '',          0,               '', 'System Master', 'System Master', 'Administrate system master data.', true),
+(10610,   10600,          9,        'admin_menu.en', 'initsystem',                    '',          0,               '', 'Database Maintenance', 'Database Maintenance', 'Database maintenance such as data initializing.', true),
+(10611,   10600,          10,        'admin_menu.en', 'editmenu',                      '',          0,               '', 'Edit Administration Menu', 'Edit Administration Menu', 'Edit administration menu.', true),
 (10699,   0,            7,        'admin_menu.en', '_699',                          '',          1,               '',          'Return', '', '', true),
 (11100,  0,            11,       'admin_menu.en', '_others',                       '',          0,                '',           'Others', '', '', true),
 (11101,  11100,         0,        'admin_menu.en', 'logout',                        '',          0,                '',                  'Logout', 'Logout', 'Logout from system.', true);
