@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainAccesslogWidgetContainer.php 3724 2010-10-23 08:58:19Z fishbone $
+ * @version    SVN: $Id: admin_mainAccesslogWidgetContainer.php 4127 2011-05-11 03:00:49Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -31,6 +31,8 @@ class admin_mainAccesslogWidgetContainer extends admin_mainBaseWidgetContainer
 	private $showMessage;		// メッセージ画面かどうか
 	private $message;			// 表示メッセージ
 	private $server;			// 指定サーバ
+	private $startDt;			// 検索範囲開始日付
+	private $endDt;				// 検索範囲終了日付
 	const DEFAULT_LIST_COUNT = 30;			// 最大リスト表示数
 	const MAX_PAGE_COUNT = 200;				// 最大ページ数
 	const INFO_ICON_FILE = '/images/system/info16.png';			// 情報アイコン
@@ -262,11 +264,11 @@ class admin_mainAccesslogWidgetContainer extends admin_mainBaseWidgetContainer
 		if (empty($this->path)) $this->path = self::DEFAULT_ACCESS_PATH;
 
 		// 期間指定を取得
-		$startDt = $request->trimValueOf('start_date');		// 検索範囲開始日付
-		if (!empty($startDt)) $startDt = $this->convertToProperDate($startDt);
-		$endDt = $request->trimValueOf('end_date');			// 検索範囲終了日付
-		if (!empty($endDt)) $endDt = $this->convertToProperDate($endDt);
-		$endNextDt = $endDt;
+		$this->startDt = $request->trimValueOf('start_date');		// 検索範囲開始日付
+		if (!empty($this->startDt)) $this->startDt = $this->convertToProperDate($this->startDt);
+		$this->endDt = $request->trimValueOf('end_date');			// 検索範囲終了日付
+		if (!empty($this->endDt)) $this->endDt = $this->convertToProperDate($this->endDt);
+		$endNextDt = $this->endDt;
 		if (!empty($endNextDt)) $endNextDt = $this->getNextDay($endNextDt);			// 翌日を取得
 		
 		// 表示条件
@@ -276,7 +278,7 @@ class admin_mainAccesslogWidgetContainer extends admin_mainBaseWidgetContainer
 		if (empty($pageNo)) $pageNo = 1;
 		
 		// 入力データのエラーチェック
-		if (!empty($startDt) && !empty($endDt) && $startDt > $endDt){
+		if (!empty($this->startDt) && !empty($this->endDt) && $this->startDt > $this->endDt){
 			$this->setUserErrorMsg('期間の指定範囲にエラーがあります。');
 		}
 		
@@ -287,7 +289,7 @@ class admin_mainAccesslogWidgetContainer extends admin_mainBaseWidgetContainer
 		} else if ($pathParam == self::ACCESS_PATH_OTHER){		// その他のパス
 			$pathParam = '';
 		}
-		$totalCount = $this->db->getAccessLogCount($pathParam, $startDt, $endNextDt);
+		$totalCount = $this->db->getAccessLogCount($pathParam, $this->startDt, $endNextDt);
 
 		// 表示するページ番号の修正
 		$pageCount = (int)(($totalCount -1) / $viewCount) + 1;		// 総ページ数
@@ -304,7 +306,11 @@ class admin_mainAccesslogWidgetContainer extends admin_mainBaseWidgetContainer
 				if ($i == $pageNo){
 					$link = ' ' . $i;
 				} else {
-					$link = ' <a href="#" onclick="selpage(\'' . $i . '\');return false;">' . $i . '</a>';
+					$detailUrl = '?task=accesslog&path=' . $this->path;
+					if (!empty($this->startDt)) $detailUrl .= '&start_date=' . $this->startDt;	// 検索範囲開始日付
+					if (!empty($this->endDt)) $detailUrl .= '&end_date=' . $this->endDt;		// 検索範囲終了日付
+					if ($i > 1) $detailUrl .= '&page=' . $i;
+					$link = '&nbsp;<a href="' . $this->convertUrlToHtmlEntity($detailUrl) . '">' . $i . '</a>';
 				}
 				$pageLink .= $link;
 			}
@@ -312,9 +318,11 @@ class admin_mainAccesslogWidgetContainer extends admin_mainBaseWidgetContainer
 		
 		// アクセスパスメニュー作成
 		$this->createPathMenu();
-			
-		$this->tmpl->addVar("_widget", "start_date", $startDt);	// 開始日付
-		$this->tmpl->addVar("_widget", "end_date", $endDt);	// 終了日付
+
+		// 値を画面に埋め込む
+		$this->tmpl->addVar("_widget", "edit_url", '?task=accesslog_detail');// アクセスログ詳細URL
+		$this->tmpl->addVar("_widget", "start_date", $this->startDt);	// 開始日付
+		$this->tmpl->addVar("_widget", "end_date", $this->endDt);	// 終了日付
 		$this->tmpl->addVar("_widget", "page_link", $pageLink);
 		$this->tmpl->addVar("_widget", "total_count", $totalCount);
 		$this->tmpl->addVar("_widget", "page", $pageNo);	// ページ番号
@@ -323,8 +331,8 @@ class admin_mainAccesslogWidgetContainer extends admin_mainBaseWidgetContainer
 		$this->tmpl->addVar("search_range", "end_no", $endNo);
 		if ($totalCount > 0) $this->tmpl->setAttribute('search_range', 'visibility', 'visible');// 検出範囲を表示
 		
-		// 運用ログを取得
-		$this->db->getAccessLogList($viewCount, $pageNo, $pathParam, array($this, 'logListLoop'), $startDt, $endNextDt);
+		// アクセスログを取得
+		$this->db->getAccessLogList($viewCount, $pageNo, $pathParam, array($this, 'logListLoop'), $this->startDt, $endNextDt);
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
 		if (count($this->serialArray) == 0) $this->tmpl->setAttribute('loglist', 'visibility', 'hidden');		// ログがないときは非表示
 	}
@@ -475,6 +483,8 @@ class admin_mainAccesslogWidgetContainer extends admin_mainBaseWidgetContainer
 	 */
 	function logListLoop($index, $fetchedRow, $param)
 	{
+		$serial = $fetchedRow['al_serial'];
+		
 		$ip = $fetchedRow['al_ip'];
 		$ipStr = $this->convertToDispString($ip);
 		if ($ip == $this->clientIp){			// クライアントのIPアドレスと同じときはグリーンで表示
@@ -524,10 +534,14 @@ class admin_mainAccesslogWidgetContainer extends admin_mainBaseWidgetContainer
 			}
 		}
 
+		// 詳細画面へのURL
+		$detailUrl = '?task=accesslog_detail&serial=' . $serial;
+		
 		$row = array(
 			'index' => $index,													// 行番号
-			'serial' => $this->convertToDispString($fetchedRow['al_serial']),			// シリアル番号
+			'serial' => $this->convertToDispString($serial),			// シリアル番号
 			'uri' => $this->convertToDispString($fetchedRow['al_uri']),		// URI
+			'detail_url' => $this->convertUrlToHtmlEntity($detailUrl),		// 詳細画面URL
 			'browser' => $browserImg,		// ブラウザ
 			'os' => $osImg,			// OS
 			'country' => $countryImg,		// 国画像
@@ -540,7 +554,7 @@ class admin_mainAccesslogWidgetContainer extends admin_mainBaseWidgetContainer
 		$this->tmpl->parseTemplate('loglist', 'a');
 		
 		// 表示中のコンテンツIDを保存
-		$this->serialArray[] = $fetchedRow['ol_serial'];
+		$this->serialArray[] = $serial;
 		return true;
 	}
 	/**
