@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainOpelogWidgetContainer.php 4116 2011-05-07 10:49:02Z fishbone $
+ * @version    SVN: $Id: admin_mainOpelogWidgetContainer.php 4126 2011-05-10 12:01:56Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -297,6 +297,9 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 		if (!empty($this->server)) $accessLogUrl .= '&_server=' . $this->server;
 		$this->tmpl->addVar("_widget", "access_log_url", $accessLogUrl);
 		
+		// 運用ログ詳細URL
+		$this->tmpl->addVar("_widget", "edit_url", '?task=opelog_detail');
+		
 		// 運用ログを取得
 		$this->db->getOpeLogList($viewLevel, $this->logStatus, $viewCount, $pageNo, array($this, 'logListLoop'));
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
@@ -384,7 +387,7 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 		$accessLogUrl = '?task=accesslog_detail&openby=simple';
 		if (!empty($this->server)) $accessLogUrl .= '&_server=' . $this->server;
 		$this->tmpl->addVar("_widget", "access_log_url", $accessLogUrl);
-
+		
 		// 一覧の表示条件
 		$this->tmpl->addVar("_widget", "page", $page);	// ページ番号
 		$this->tmpl->addVar("_widget", "view_count", $viewCount);	// 最大表示項目数
@@ -409,6 +412,8 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 	 */
 	function logListLoop($index, $fetchedRow, $param)
 	{
+		$serial = $fetchedRow['ol_serial'];
+				
 		$msgChecked = '';
 		if ($fetchedRow['ol_checked']){
 			$msgChecked = 'checked';
@@ -452,11 +457,15 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 			}
 		}
 		
+		// メッセージのリンク先
+		$messageUrl = '?task=opelog_detail&serial=' . $serial;
+		
 		$row = array(
 			'index' => $index,													// 行番号
-			'serial' => $this->convertToDispString($fetchedRow['ol_serial']),			// シリアル番号
+			'serial' => $this->convertToDispString($serial),			// シリアル番号
 			'type' => $iconTag,			// メッセージタイプを示すアイコン
 			'message' => $this->convertToDispString($fetchedRow['ol_message']),		// メッセージ
+			'url' => $this->convertUrlToHtmlEntity($messageUrl),			// メッセージのリンク先
 			'ip' => $ipStr,		// クライアントIP
 			'access_log' => $accessLog,		// アクセスログ番号
 			'browser' => $browserImg,		// ブラウザ
@@ -468,7 +477,7 @@ class admin_mainOpelogWidgetContainer extends admin_mainBaseWidgetContainer
 		$this->tmpl->parseTemplate('loglist', 'a');
 		
 		// 表示中のコンテンツIDを保存
-		$this->serialArray[] = $fetchedRow['ol_serial'];
+		$this->serialArray[] = $serial;
 		return true;
 	}
 	/**
