@@ -10,7 +10,7 @@
  * @author     株式会社 毎日メディアサービス
  * @copyright  Copyright 2009-2010 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_contactus_freelayoutWidgetContainer.php 2853 2010-02-14 15:36:19Z fishbone $
+ * @version    SVN: $Id: admin_contactus_freelayoutWidgetContainer.php 2976 2010-03-27 06:27:18Z fishbone $
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -110,10 +110,10 @@ class admin_contactus_freelayoutWidgetContainer extends BaseAdminWidgetContainer
 		$defs = $request->trimValueOf('item_def');		// お問い合わせ項目定義
 		$values = $request->trimValueOf('required');		// お問い合わせ項目必須入力
 		$requireds = array();
-		if (!empty($values)) $requireds = explode(',', $values);
+		if (strlen($values) > 0) $requireds = explode(',', $values);
 		$values = $request->trimValueOf('titlevisible');		// お問い合わせ項目タイトル表示制御
 		$titleVisibles = array();
-		if (!empty($values)) $titleVisibles = explode(',', $values);
+		if (strlen($values) > 0) $titleVisibles = explode(',', $values);
 		$emailSubject = $request->trimValueOf('email_subject');		// メールタイトル
 		$emailReceiver = trim($request->valueOf('email_receiver'));	// メール受信者(aaaa<xxx@xxx.xxx>形式が可能)
 		
