@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_contentWidgetContainer.php 3987 2011-02-10 05:10:25Z fishbone $
+ * @version    SVN: $Id: default_contentWidgetContainer.php 4054 2011-04-01 01:00:07Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -105,12 +105,19 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 		$this->currentPageUrl = $this->gEnv->createCurrentPageUrl();// 現在のページURL
 		$this->isSystemManageUser = $this->gEnv->isSystemManageUser();	// システム運用可能ユーザかどうか
 		$cmd = $request->trimValueOf(M3_REQUEST_PARAM_OPERATION_COMMAND);
-				
+		
+		// 履歴インデックス
+		$historyIndex = -1;
+		$value = $request->trimValueOf(M3_REQUEST_PARAM_HISTORY);		// 履歴インデックス
+		if ($value != '') $historyIndex = intval($value);
+		
 		// 管理者でプレビューモードのときは表示制限しない
 		$preview = false;
 		if ($this->isSystemManageUser && $cmd == M3_REQUEST_CMD_PREVIEW){		// システム運用者以上
 			$preview = true;
 		}
+		// プレビューでないときは履歴表示不可
+		if (!$preview) $historyIndex = -1;
 		
 		// ログインユーザでないときは、ユーザ制限のない項目だけ表示
 		$all = false;
@@ -128,6 +135,8 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 			$messageDeny = $paramObj->messageDeny;							// アクセス不可の場合のメッセージ
 			$this->showEdit = $paramObj->showEdit;			// 編集ボタンを表示するかどうか
 		}
+		// プレビューモードで履歴表示のときは編集ボタンを表示しない
+		if ($preview && $historyIndex >= 0) $this->showEdit = 0;
 
 		$this->pageTitle = '';		// 画面タイトル、パンくずリスト用タイトル
 		$act = $request->trimValueOf('act');
@@ -188,18 +197,22 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 					$this->db->getContentItems(array($this, 'itemsLoop'), $contentIdArray, $this->gEnv->getDefaultLanguage(), $all, $now, $preview);
 				}
 			} else {	// コンテンツIDで指定
-				// データエラーチェック
-				$contentIdArray = explode(',', $contentid);
-				if (ValueCheck::isNumeric($contentIdArray)){		// すべて数値であるかチェック
-					$this->db->getContentItems(array($this, 'itemsLoop'), $contentIdArray, $this->gEnv->getCurrentLanguage(), $all, $now, $preview);
-					if (!$this->_contentCreated){		// コンテンツが取得できなかったときはデフォルト言語で取得
-						$this->db->getContentItems(array($this, 'itemsLoop'), $contentIdArray, $this->gEnv->getDefaultLanguage(), $all, $now, $preview);
-					}
-				
-					// コンテンツアクセス不可のときはアクセス不可メッセージを出力
-					if ($showMessageDeny && !$this->_contentCreated) $this->setAppErrorMsg($messageDeny);
+				if ($historyIndex >= 0){		// 履歴表示のとき
+					$this->db->getContentItemsByHistory(array($this, 'itemsLoop'), $contentid, $this->gEnv->getCurrentLanguage(), $historyIndex);
 				} else {
-					$this->setAppErrorMsg('IDにエラー値があります');
+					// データエラーチェック
+					$contentIdArray = explode(',', $contentid);
+					if (ValueCheck::isNumeric($contentIdArray)){		// すべて数値であるかチェック
+						$this->db->getContentItems(array($this, 'itemsLoop'), $contentIdArray, $this->gEnv->getCurrentLanguage(), $all, $now, $preview);
+						if (!$this->_contentCreated){		// コンテンツが取得できなかったときはデフォルト言語で取得
+							$this->db->getContentItems(array($this, 'itemsLoop'), $contentIdArray, $this->gEnv->getDefaultLanguage(), $all, $now, $preview);
+						}
+				
+						// コンテンツアクセス不可のときはアクセス不可メッセージを出力
+						if ($showMessageDeny && !$this->_contentCreated) $this->setAppErrorMsg($messageDeny);
+					} else {
+						$this->setAppErrorMsg('IDにエラー値があります');
+					}
 				}
 			}
 		}
