@@ -8,15 +8,17 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_test_installInstallWidgetContainer.php 133 2007-12-16 04:29:48Z fishbone $
+ * @version    SVN: $Id: admin_test_installInstallWidgetContainer.php 3319 2010-06-30 09:10:50Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() .	'/baseInstallWidgetContainer.php');
 
 class admin_test_installInstallWidgetContainer extends BaseInstallWidgetContainer
 {
+	const CURRENT_VERSION = '1.1.0';		// 現在のバージョン
+	
 	/**
 	 * コンストラクタ
 	 */
@@ -55,21 +57,29 @@ class admin_test_installInstallWidgetContainer extends BaseInstallWidgetContaine
 	 * 実行するSQLスクリプトファイル名を実行順に配列で返す。
 	 *
 	 * @param RequestManager $request		HTTPリクエスト処理クラス
-	 * @param int $install					インストール種別(0=インストール、1=アンインストール、2=アップグレード)
-	 * @return なし
+	 * @param int $install					インストール種別(0=インストール、1=アンインストール、2=アップデート)
+	 * @param string $version				現在のバージョン
+	 * @return array						実行するスクリプトの配列
 	 */
-	function _doScript($request, $install)
+	function _doScript($request, $install, $version)
 	{
+		$scripts = array();
+		
 		switch ($install){
 			case 0:		// インストール
-				return array('install.sql');
+				$scripts[] = 'install.sql';
+				break;
 			case 1:		// アンインストール
-				return array('uninstall.sql');
-			case 2:		// アップグレード
+				$scripts[] = 'uninstall.sql';
+				break;
+			case 2:		// アップデート
+				// ウィジェットのバージョンを確認
+				if (version_compare($version, self::CURRENT_VERSION) < 0) $scripts[] = 'update.sql';
 				break;
 			default:
 				break;
 		}
+		return $scripts;
 	}
 }
 ?>
